@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -79,36 +79,51 @@ public final class MailNotifyPushListener implements PushListener {
      * Initializes a new {@link MailNotifyPushListener}.
      *
      * @param session The needed session to obtain and connect mail access instance
+     * @param permanent <code>true</code> for permanent listener; otherwise <code>false</code>
      * @return A new {@link MailNotifyPushListener}.
      */
-    public static MailNotifyPushListener newInstance(final Session session) {
-        return new MailNotifyPushListener(session);
+    public static MailNotifyPushListener newInstance(Session session, boolean permanent) {
+        return new MailNotifyPushListener(session, permanent);
     }
 
-    /*
-     * Member section
+    /*-
+     * ------------------------------------------------- Member section -------------------------------------------------
      */
 
     private final Session session;
-
     private final int userId;
-
     private final int contextId;
-
-    private volatile boolean started;
+    private final boolean permanent;
 
     /**
      * Initializes a new {@link MailNotifyPushListener}.
-     *
-     * @param session The needed session to obtain and connect mail access instance
      */
-    private MailNotifyPushListener(final Session session) {
+    private MailNotifyPushListener(Session session, boolean permanent) {
         super();
+        this.permanent = permanent;
         this.session = session;
         this.userId = session.getUserId();
         this.contextId = session.getContextId();
     }
 
+    /**
+     * Gets the permanent flag
+     *
+     * @return The permanent flag
+     */
+    public boolean isPermanent() {
+        return permanent;
+    }
+
+    /**
+     * Gets the associated session
+     *
+     * @return The associated session
+     */
+    public Session getSession() {
+        return session;
+    }
+
     @Override
     public String toString() {
         final StringBuilder sb = new StringBuilder(128).append("session-ID=").append(session.getSessionID());
@@ -116,34 +131,9 @@ public final class MailNotifyPushListener implements PushListener {
         return sb.toString();
     }
 
-    /**
-     * Opens this listener (if {@link #isIgnoreOnGlobal()} returns <code>false</code>).
-     *
-     * @throws OXException If listener cannot be opened
-     */
-    public void open() throws OXException {
-        // Nothing to do
-    }
-
-    /**
-     * Closes this listener.
-     */
-    public void close() {
-        // NOthing to do
-    }
-
     @Override
     public void notifyNewMail() throws OXException {
-        PushUtility.triggerOSGiEvent(MailFolderUtility.prepareFullname(ACCOUNT_ID, "INBOX"), session, /* Distribute remotely! */ true);
-    }
-
-    /**
-     * Checks if this listener has been started.
-     *
-     * @return <code>true</code> if this listener has been started; otherwise <code>false</code>
-     */
-    public boolean isStarted() {
-        return started;
+        PushUtility.triggerOSGiEvent(MailFolderUtility.prepareFullname(ACCOUNT_ID, "INBOX"), session, null, /* Distribute remotely! */ true, false);
     }
 
 }
